@@ -46,8 +46,13 @@ def build_segment(model, segment, attr):
 
     # Resolve the inner-most path segment.
     if segment.path:
-        return col.has(build_segment(
-            col.property.mapper.class_, segment, attr))
+        if col.impl.accepts_scalar_loader:
+            return col.has(build_segment(
+                col.property.mapper.class_, segment, attr))
+
+        else:
+            return col.any(build_segment(
+                col.property.mapper.class_, segment, attr))
 
     # Determine the operator.
     op = OPERATOR_MAP[segment.operator]
